@@ -1,6 +1,6 @@
 use swc_atoms::JsWord;
 use swc_ecma_ast::*;
-use swc_ecma_visit::{noop_visit_type, Node, Visit, VisitWith};
+use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 
 pub(super) struct UsedNameCollector<'a> {
     pub used_names: &'a mut Vec<JsWord>,
@@ -9,7 +9,7 @@ pub(super) struct UsedNameCollector<'a> {
 macro_rules! noop {
     ($name:ident, $T:path) => {
         /// no-op
-        fn $name(&mut self, _: &$T, _: &dyn Node) {}
+        fn $name(&mut self, _: &$T) {}
     };
 }
 
@@ -23,7 +23,7 @@ impl<'a> Visit for UsedNameCollector<'a> {
     noop!(visit_method_prop, MethodProp);
     noop!(visit_constructor, Constructor);
 
-    fn visit_expr(&mut self, expr: &Expr, _: &dyn Node) {
+    fn visit_expr(&mut self, expr: &Expr) {
         match *expr {
             Expr::Ident(ref i) => self.used_names.push(i.sym.clone()),
             _ => expr.visit_children_with(self),
