@@ -175,19 +175,16 @@ impl VisitMut for PrivateInObject {
             }
 
             for m in &mut n.body {
-                match m {
-                    ClassMember::Constructor(Constructor {
-                        body: Some(body), ..
-                    }) => {
-                        for expr in take(&mut self.cls.constructor_exprs) {
-                            body.stmts.push(Stmt::Expr(ExprStmt {
-                                span: DUMMY_SP,
-                                expr,
-                            }));
-                        }
+                if let ClassMember::Constructor(Constructor {
+                    body: Some(body), ..
+                }) = m
+                {
+                    for expr in take(&mut self.cls.constructor_exprs) {
+                        body.stmts.push(Stmt::Expr(ExprStmt {
+                            span: DUMMY_SP,
+                            expr,
+                        }));
                     }
-
-                    _ => {}
                 }
             }
         }
@@ -367,27 +364,12 @@ impl VisitMut for PrivateInObject {
                     args: vec![right.take().as_arg()],
                     type_args: Default::default(),
                 });
-                return;
             }
 
             _ => {}
         }
     }
 
-    fn visit_mut_member_expr(&mut self, e: &mut MemberExpr) {
-        e.obj.visit_mut_with(self);
-
-        if let MemberProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
-    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
-        if let SuperProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
     fn visit_mut_module_items(&mut self, ns: &mut Vec<ModuleItem>) {
         ns.visit_mut_children_with(self);
 
@@ -427,17 +409,14 @@ impl VisitMut for PrivateInObject {
 
                     let add_to_checker = Box::new(Expr::Call(CallExpr {
                         span: DUMMY_SP,
-                        callee: var_name
-                            .clone()
-                            .make_member(quote_ident!("add"))
-                            .as_callee(),
+                        callee: var_name.make_member(quote_ident!("add")).as_callee(),
                         args: vec![ThisExpr { span: DUMMY_SP }.as_arg()],
                         type_args: Default::default(),
                     }));
 
                     *init = Box::new(Expr::Seq(SeqExpr {
                         span: init_span,
-                        exprs: vec![assign, add_to_checker, Box::new(tmp.clone().into())],
+                        exprs: vec![assign, add_to_checker, Box::new(tmp.into())],
                     }));
                 }
                 None => {
@@ -446,10 +425,7 @@ impl VisitMut for PrivateInObject {
                         op: op!("void"),
                         arg: Box::new(Expr::Call(CallExpr {
                             span: DUMMY_SP,
-                            callee: var_name
-                                .clone()
-                                .make_member(quote_ident!("add"))
-                                .as_callee(),
+                            callee: var_name.make_member(quote_ident!("add")).as_callee(),
                             args: vec![ThisExpr { span: DUMMY_SP }.as_arg()],
                             type_args: Default::default(),
                         })),
@@ -460,12 +436,8 @@ impl VisitMut for PrivateInObject {
     }
 
     fn visit_mut_prop_name(&mut self, n: &mut PropName) {
-        match n {
-            PropName::Computed(_) => {
-                n.visit_mut_children_with(self);
-            }
-
-            _ => {}
+        if let PropName::Computed(_) = n {
+            n.visit_mut_children_with(self);
         }
     }
 
@@ -498,12 +470,8 @@ impl Visit for ClassAnalyzer<'_> {
         n.visit_children_with(self);
 
         if n.op == op!("in") {
-            match &*n.left {
-                Expr::PrivateName(left) => {
-                    self.brand_check_names.insert(left.id.sym.clone());
-                }
-
-                _ => {}
+            if let Expr::PrivateName(left) = &*n.left {
+                self.brand_check_names.insert(left.id.sym.clone());
             }
         }
     }
