@@ -1717,20 +1717,25 @@ test!(
     "
     var regeneratorRuntime = require('regenerator-runtime');
     export default function Foo() {
-        return call(_asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
-            return regeneratorRuntime.wrap(function _callee$(_ctx) {
-                while(1)switch(_ctx.prev = _ctx.next){
-                    case 0:
-                        _ctx.next = 2;
-                        return doSomething();
-                    case 2:
-                    case 'end':
-                        return _ctx.stop();
-                }
-            }, _callee);
-        })));
+        return call(function() {
+            var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
+                return regeneratorRuntime.wrap(function _callee$(_ctx) {
+                    while(1)switch(_ctx.prev = _ctx.next){
+                        case 0:
+                            _ctx.next = 2;
+                            return doSomething();
+                        case 2:
+                        case 'end':
+                            return _ctx.stop();
+                    }
+                }, _callee);
+            }));
+            return function(e) {
+                return _ref.apply(this, arguments);
+            };
+        }());
     }
-    "
+"
 );
 
 test!(
@@ -1751,20 +1756,25 @@ test!(
     "
     var regeneratorRuntime = require('regenerator-runtime');
     export default function Foo() {
-        return call(_asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
-            return regeneratorRuntime.wrap(function _callee$(_ctx) {
-                while(1)switch(_ctx.prev = _ctx.next){
-                    case 0:
-                        _ctx.next = 2;
-                        return doSomething();
-                    case 2:
-                    case 'end':
-                        return _ctx.stop();
-                }
-            }, _callee);
-        })));
+        return call(function() {
+            var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
+                return regeneratorRuntime.wrap(function _callee$(_ctx) {
+                    while(1)switch(_ctx.prev = _ctx.next){
+                        case 0:
+                            _ctx.next = 2;
+                            return doSomething();
+                        case 2:
+                        case 'end':
+                            return _ctx.stop();
+                    }
+                }, _callee);
+            }));
+            return function(e) {
+                return _ref.apply(this, arguments);
+            };
+        }());
     }
-    "
+"
 );
 
 test!(
@@ -1786,20 +1796,25 @@ test!(
     "
     var regeneratorRuntime = require('regenerator-runtime');
     export default function Foo() {
-        return call(_asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
-            return regeneratorRuntime.wrap(function _callee$(_ctx) {
-                while(1)switch(_ctx.prev = _ctx.next){
-                    case 0:
-                        _ctx.next = 2;
-                        return doSomething();
-                    case 2:
-                    case 'end':
-                        return _ctx.stop();
-                }
-            }, _callee);
-        })));
+        return call(function() {
+            var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
+                return regeneratorRuntime.wrap(function _callee$(_ctx) {
+                    while(1)switch(_ctx.prev = _ctx.next){
+                        case 0:
+                            _ctx.next = 2;
+                            return doSomething();
+                        case 2:
+                        case 'end':
+                            return _ctx.stop();
+                    }
+                }, _callee);
+            }));
+            return function(e) {
+                return _ref.apply(this, arguments);
+            };
+        }());
     }
-    "
+"
 );
 
 test!(
@@ -1824,20 +1839,25 @@ test!(
     "
     var regeneratorRuntime = require('regenerator-runtime');
     export default function Foo() {
-        return call(_asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
-            return regeneratorRuntime.wrap(function _callee$(_ctx) {
-                while(1)switch(_ctx.prev = _ctx.next){
-                    case 0:
-                        _ctx.next = 2;
-                        return doSomething();
-                    case 2:
-                    case 'end':
-                        return _ctx.stop();
-                }
-            }, _callee);
-        })));
+        return call(function() {
+            var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(e) {
+                return regeneratorRuntime.wrap(function _callee$(_ctx) {
+                    while(1)switch(_ctx.prev = _ctx.next){
+                        case 0:
+                            _ctx.next = 2;
+                            return doSomething();
+                        case 2:
+                        case 'end':
+                            return _ctx.stop();
+                    }
+                }, _callee);
+            }));
+            return function(e) {
+                return _ref.apply(this, arguments);
+            };
+        }());
     }
-    "
+"
 );
 
 test!(
